@@ -37,6 +37,7 @@
 #define ADJUSTMENT_MAX_NORMAL 65536.0 /* PA_VOLUME_NORM */
 #define ADJUSTMENT_MAX_AMPLIFIED 98304.0 /* 1.5 * ADJUSTMENT_MAX_NORMAL */
 #define ADJUSTMENT_MAX (bar->priv->is_amplified ? ADJUSTMENT_MAX_AMPLIFIED : ADJUSTMENT_MAX_NORMAL)
+#define SCROLLSTEP (ADJUSTMENT_MAX / 100.0 * 5.0)
 
 #define GVC_CHANNEL_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GVC_TYPE_CHANNEL_BAR, GvcChannelBarPrivate))
 
@@ -220,7 +221,7 @@ update_layout (GvcChannelBar *bar)
         }
 
         box = bar->priv->scale_box;
-        frame = box->parent;
+        frame = gtk_widget_get_parent (box);
 
         g_object_ref (bar->priv->image);
         g_object_ref (bar->priv->label);
@@ -411,14 +412,9 @@ on_scale_button_release_event (GtkWidget      *widget,
 
         value = gtk_adjustment_get_value (adj);
 
-        if (bar->priv->show_mute == FALSE) {
-                /* this means the adjustment moved away from zero and
-                 * therefore we should unmute and set the volume. */
-                if (value > 0)
-                        gvc_channel_bar_set_is_muted (bar, FALSE);
-                else
-                        gvc_channel_bar_set_is_muted (bar, TRUE);
-        }
+        /* this means the adjustment moved away from zero and
+         * therefore we should unmute and set the volume. */
+        gvc_channel_bar_set_is_muted (bar, (value == 0.0));
 
         /* Play a sound! */
         ca_gtk_play_for_widget (GTK_WIDGET (bar), 0,
@@ -453,15 +449,15 @@ gvc_channel_bar_scroll (GvcChannelBar *bar, GdkScrollDirection direction)
         value = gtk_adjustment_get_value (adj);
 
         if (direction == GDK_SCROLL_UP) {
-                if (value + ADJUSTMENT_MAX/100.0 > ADJUSTMENT_MAX)
+                if (value + SCROLLSTEP > ADJUSTMENT_MAX)
                         value = ADJUSTMENT_MAX;
                 else
-                        value = value + ADJUSTMENT_MAX/100.0;
+                        value = value + SCROLLSTEP;
         } else if (direction == GDK_SCROLL_DOWN) {
-                if (value - ADJUSTMENT_MAX/100.0 < 0)
+                if (value - SCROLLSTEP < 0)
                         value = 0.0;
                 else
-                        value = value - ADJUSTMENT_MAX/100.0;
+                        value = value - SCROLLSTEP;
         }
 
         gvc_channel_bar_set_is_muted (bar, (value == 0.0));
@@ -596,6 +592,12 @@ gvc_channel_bar_set_is_amplified (GvcChannelBar *bar, gboolean amplified)
                         str = g_strdup_printf ("<small>%s</small>", C_("volume", "Unamplified"));
                         gtk_scale_add_mark (GTK_SCALE (bar->priv->scale), bar->priv->base_volume,
                                             GTK_POS_BOTTOM, str);
+                        /* Only show 100% if it's higher than the base volume */
+                        if (bar->priv->base_volume < ADJUSTMENT_MAX_NORMAL) {
+                                str = g_strdup_printf ("<small>%s</small>", C_("volume", "100%"));
+                                gtk_scale_add_mark (GTK_SCALE (bar->priv->scale), ADJUSTMENT_MAX_NORMAL,
+                                                    GTK_POS_BOTTOM, str);
+                        }
                 }
 
                 g_free (str);
