@@ -1,7 +1,28 @@
+/* audio-profile.c: */
+
+/*
+ * Copyright (C) 2003 Thomas Vander Stichele
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gst/gst.h>
 
-#include <glib/gi18n.h>
 #include "gmp-util.h"
 #include "audio-profile.h"
 #include "audio-profile-private.h"
@@ -41,8 +62,6 @@ enum {
   LAST_SIGNAL
 };
 
-static void gm_audio_profile_init        (GMAudioProfile      *profile);
-static void gm_audio_profile_class_init  (GMAudioProfileClass *klass);
 static void gm_audio_profile_finalize    (GObject              *object);
 
 static void gm_audio_profile_update      (GMAudioProfile *profile);
@@ -62,49 +81,18 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 static gpointer parent_class;
 
-/*
- * GObject stuff
- */
-
-GType
-gm_audio_profile_get_type (void)
-{
-  static GType object_type = 0;
-
-  g_type_init ();
-
-  if (!object_type)
-    {
-      static const GTypeInfo object_info =
-      {
-        sizeof (GMAudioProfileClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) gm_audio_profile_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (GMAudioProfile),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) gm_audio_profile_init,
-      };
-      object_type = g_type_register_static (G_TYPE_OBJECT,
-                                            "GMAudioProfile",
-                                            &object_info, 0);
-    }
-
-  return object_type;
-}
+G_DEFINE_TYPE (GMAudioProfile, gm_audio_profile, G_TYPE_OBJECT)
 
 static void
-gm_audio_profile_init (GMAudioProfile *profile)
+gm_audio_profile_init (GMAudioProfile *self)
 {
   g_return_if_fail (profiles != NULL);
 
-  profile->priv = g_new0 (GMAudioProfilePrivate, 1);
-  profile->priv->name = g_strdup (_("<no name>"));
-  profile->priv->description = g_strdup (_("<no description>"));
-  profile->priv->pipeline = g_strdup ("identity");
-  profile->priv->extension = g_strdup ("wav");
+  self->priv = g_new0 (GMAudioProfilePrivate, 1);
+  self->priv->name = g_strdup (_("<no name>"));
+  self->priv->description = g_strdup (_("<no description>"));
+  self->priv->pipeline = g_strdup ("identity");
+  self->priv->extension = g_strdup ("wav");
 }
 
 static void
@@ -138,19 +126,19 @@ gm_audio_profile_class_init (GMAudioProfileClass *klass)
 static void
 gm_audio_profile_finalize (GObject *object)
 {
-  GMAudioProfile *profile;
+  GMAudioProfile *self;
 
-  profile = GM_AUDIO_PROFILE (object);
+  self = GM_AUDIO_PROFILE (object);
 
-  gm_audio_profile_forget (profile);
+  gm_audio_profile_forget (self);
 
-  gconf_client_notify_remove (profile->priv->conf,
-                              profile->priv->notify_id);
-  profile->priv->notify_id = 0;
+  gconf_client_notify_remove (self->priv->conf,
+                              self->priv->notify_id);
+  self->priv->notify_id = 0;
 
-  g_object_unref (G_OBJECT (profile->priv->conf));
+  g_object_unref (G_OBJECT (self->priv->conf));
 
-  g_free (profile->priv->name);
+  g_free (self->priv->name);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -197,13 +185,13 @@ gm_audio_profile_sync_list (gboolean use_this_list,
   gboolean need_new_default;
   GMAudioProfile *fallback;
 
-  GMP_DEBUG("sync_list: start\n");
+  GST_DEBUG ("sync_list: start\n");
   if (use_this_list)
-    GMP_DEBUG("Using given list of length %d\n", g_slist_length (this_list));
+    GST_DEBUG ("Using given list of length %d\n", g_slist_length (this_list));
   else
-    GMP_DEBUG("using list from gconf\n");
+    GST_DEBUG ("using list from gconf\n");
   known = gm_audio_profile_get_list ();
-    GMP_DEBUG("list of known profiles: size %d\n", g_list_length (known));
+    GST_DEBUG ("list of known profiles: size %d\n", g_list_length (known));
 
   if (use_this_list)
     {
@@ -223,7 +211,7 @@ gm_audio_profile_sync_list (gboolean use_this_list,
         }
     }
 
-  GMP_DEBUG("updated: slist of %d items\n", g_slist_length (updated));
+  GST_DEBUG ("updated: slist of %d items\n", g_slist_length (updated));
   /* Add any new ones; ie go through updated and if any of them isn't in
    * the hash yet, add it.  If it is in the list of known profiles,  remove
    * it from our copy of that list. */
@@ -237,7 +225,7 @@ gm_audio_profile_sync_list (gboolean use_this_list,
       if (link)
         {
           /* make known point to profiles we didn't find in the list */
-          GMP_DEBUG("id %s found in known profiles list, deleting from known\n",
+          GST_DEBUG ("id %s found in known profiles list, deleting from known\n",
                     (char *) tmp_slist->data);
           known = g_list_delete_link (known, link);
         }
@@ -245,7 +233,7 @@ gm_audio_profile_sync_list (gboolean use_this_list,
         {
           GMAudioProfile *profile;
 
-          GMP_DEBUG("adding new profile with id %s to global hash\n",
+          GST_DEBUG ("adding new profile with id %s to global hash\n",
                    (const char *) tmp_slist->data);
           profile = gm_audio_profile_new (tmp_slist->data, _conf);
 
@@ -271,7 +259,7 @@ gm_audio_profile_sync_list (gboolean use_this_list,
 
       forgotten = GM_AUDIO_PROFILE (tmp_list->data);
 
-      GMP_DEBUG("sync_list: forgetting profile with id %s\n",
+      GST_DEBUG ("sync_list: forgetting profile with id %s\n",
                gm_audio_profile_get_id (forgotten));
       gm_audio_profile_forget (forgotten);
 
@@ -279,7 +267,7 @@ gm_audio_profile_sync_list (gboolean use_this_list,
     }
 
   g_list_free (known);
-  GMP_DEBUG("sync_list: stop\n");
+  GST_DEBUG ("sync_list: stop\n");
 
   //FIXME: g_assert (terminal_profile_get_count () > 0);
 }
@@ -294,42 +282,42 @@ gm_audio_profile_sync_list (gboolean use_this_list,
 GMAudioProfile*
 gm_audio_profile_new (const char *id, GConfClient *conf)
 {
-  GMAudioProfile *profile;
+  GMAudioProfile *self;
   GError *err;
 
-  GMP_DEBUG("creating new GMAudioProfile for id %s\n", id);
+  GST_DEBUG ("creating new GMAudioProfile for id %s\n", id);
   g_return_val_if_fail (profiles != NULL, NULL);
   g_return_val_if_fail (gm_audio_profile_lookup (id) == NULL, NULL);
 
-  profile = g_object_new (GM_AUDIO_TYPE_PROFILE, NULL);
+  self = g_object_new (GM_AUDIO_TYPE_PROFILE, NULL);
 
-  profile->priv->conf = conf;
+  self->priv->conf = conf;
   g_object_ref (G_OBJECT (conf));
 
-  profile->priv->id = g_strdup (id);
-  profile->priv->profile_dir = gconf_concat_dir_and_key (CONF_PROFILES_PREFIX,
-                                                         profile->priv->id);
+  self->priv->id = g_strdup (id);
+  self->priv->profile_dir = gconf_concat_dir_and_key (CONF_PROFILES_PREFIX,
+                                                         self->priv->id);
 
   err = NULL;
-  GMP_DEBUG("loading config from GConf dir %s\n",
-           profile->priv->profile_dir);
-  gconf_client_add_dir (conf, profile->priv->profile_dir,
+  GST_DEBUG ("loading config from GConf dir %s\n",
+           self->priv->profile_dir);
+  gconf_client_add_dir (conf, self->priv->profile_dir,
                         GCONF_CLIENT_PRELOAD_ONELEVEL,
                         &err);
   if (err)
     {
       g_printerr ("There was an error loading config from %s. (%s)\n",
-                    profile->priv->profile_dir, err->message);
+                    self->priv->profile_dir, err->message);
       g_error_free (err);
     }
 
   err = NULL;
-  GMP_DEBUG("adding notify for GConf profile\n");
-  profile->priv->notify_id =
+  GST_DEBUG ("adding notify for GConf profile\n");
+  self->priv->notify_id =
     gconf_client_notify_add (conf,
-                             profile->priv->profile_dir,
+                             self->priv->profile_dir,
                              profile_change_notify,
-                             profile,
+                             self,
                              NULL, &err);
 
   if (err)
@@ -339,11 +327,11 @@ gm_audio_profile_new (const char *id, GConfClient *conf)
       g_error_free (err);
     }
 
-  GMP_DEBUG("inserting in hash table done\n");
-  g_hash_table_insert (profiles, profile->priv->id, profile);
-  GMP_DEBUG("audio_profile_new done\n");
+  GST_DEBUG ("inserting in hash table done\n");
+  g_hash_table_insert (profiles, self->priv->id, self);
+  GST_DEBUG ("audio_profile_new done\n");
 
-  return profile;
+  return self;
 }
 
 /*
@@ -351,29 +339,29 @@ gm_audio_profile_new (const char *id, GConfClient *conf)
  */
 
 const char*
-gm_audio_profile_get_id (GMAudioProfile *profile)
+gm_audio_profile_get_id (GMAudioProfile *self)
 {
-  return profile->priv->id;
+  return self->priv->id;
 }
 
 const char*
-gm_audio_profile_get_name (GMAudioProfile *profile)
+gm_audio_profile_get_name (GMAudioProfile *self)
 {
-  return profile->priv->name;
+  return self->priv->name;
 }
 
 void
-gm_audio_profile_set_name (GMAudioProfile *profile,
+gm_audio_profile_set_name (GMAudioProfile *self,
                         const char      *name)
 {
   char *key;
 
-  RETURN_IF_NOTIFYING (profile);
+  RETURN_IF_NOTIFYING (self);
 
-  key = gconf_concat_dir_and_key (profile->priv->profile_dir,
+  key = gconf_concat_dir_and_key (self->priv->profile_dir,
                                   KEY_NAME);
 
-  gconf_client_set_string (profile->priv->conf,
+  gconf_client_set_string (self->priv->conf,
                            key,
                            name,
                            NULL);
@@ -382,23 +370,23 @@ gm_audio_profile_set_name (GMAudioProfile *profile,
 }
 
 const char*
-gm_audio_profile_get_description (GMAudioProfile *profile)
+gm_audio_profile_get_description (GMAudioProfile *self)
 {
-  return profile->priv->description;
+  return self->priv->description;
 }
 
 void
-gm_audio_profile_set_description (GMAudioProfile *profile,
+gm_audio_profile_set_description (GMAudioProfile *self,
                                const char   *description)
 {
   char *key;
 
-  RETURN_IF_NOTIFYING (profile);
+  RETURN_IF_NOTIFYING (self);
 
-  key = gconf_concat_dir_and_key (profile->priv->profile_dir,
+  key = gconf_concat_dir_and_key (self->priv->profile_dir,
                                   KEY_DESCRIPTION);
 
-  gconf_client_set_string (profile->priv->conf,
+  gconf_client_set_string (self->priv->conf,
                            key,
                            description,
                            NULL);
@@ -407,23 +395,23 @@ gm_audio_profile_set_description (GMAudioProfile *profile,
 }
 
 const char*
-gm_audio_profile_get_pipeline (GMAudioProfile *profile)
+gm_audio_profile_get_pipeline (GMAudioProfile *self)
 {
-  return profile->priv->pipeline;
+  return self->priv->pipeline;
 }
 
 void
-gm_audio_profile_set_pipeline (GMAudioProfile *profile,
+gm_audio_profile_set_pipeline (GMAudioProfile *self,
                             const char   *pipeline)
 {
   char *key;
 
-  RETURN_IF_NOTIFYING (profile);
+  RETURN_IF_NOTIFYING (self);
 
-  key = gconf_concat_dir_and_key (profile->priv->profile_dir,
+  key = gconf_concat_dir_and_key (self->priv->profile_dir,
                                   KEY_PIPELINE);
 
-  gconf_client_set_string (profile->priv->conf,
+  gconf_client_set_string (self->priv->conf,
                            key,
                            pipeline,
                            NULL);
@@ -432,23 +420,23 @@ gm_audio_profile_set_pipeline (GMAudioProfile *profile,
 }
 
 const char*
-gm_audio_profile_get_extension (GMAudioProfile *profile)
+gm_audio_profile_get_extension (GMAudioProfile *self)
 {
-  return profile->priv->extension;
+  return self->priv->extension;
 }
 
 void
-gm_audio_profile_set_extension (GMAudioProfile *profile,
+gm_audio_profile_set_extension (GMAudioProfile *self,
                                const char   *extension)
 {
   char *key;
 
-  RETURN_IF_NOTIFYING (profile);
+  RETURN_IF_NOTIFYING (self);
 
-  key = gconf_concat_dir_and_key (profile->priv->profile_dir,
+  key = gconf_concat_dir_and_key (self->priv->profile_dir,
                                   KEY_EXTENSION);
 
-  gconf_client_set_string (profile->priv->conf,
+  gconf_client_set_string (self->priv->conf,
                            key,
                            extension,
                            NULL);
@@ -457,23 +445,23 @@ gm_audio_profile_set_extension (GMAudioProfile *profile,
 }
 
 gboolean
-gm_audio_profile_get_active (GMAudioProfile *profile)
+gm_audio_profile_get_active (GMAudioProfile *self)
 {
-  return profile->priv->active;
+  return self->priv->active;
 }
 
 void
-gm_audio_profile_set_active (GMAudioProfile *profile,
+gm_audio_profile_set_active (GMAudioProfile *self,
                           gboolean active)
 {
   char *key;
 
-  RETURN_IF_NOTIFYING (profile);
+  RETURN_IF_NOTIFYING (self);
 
-  key = gconf_concat_dir_and_key (profile->priv->profile_dir,
+  key = gconf_concat_dir_and_key (self->priv->profile_dir,
                                   KEY_ACTIVE);
 
-  gconf_client_set_bool (profile->priv->conf,
+  gconf_client_set_bool (self->priv->conf,
                          key,
                          active,
                          NULL);
@@ -485,18 +473,18 @@ gm_audio_profile_set_active (GMAudioProfile *profile,
  */
 
 static gboolean
-set_name (GMAudioProfile *profile,
+set_name (GMAudioProfile *self,
           const char *candidate_name)
 {
   /* don't update if it's the same as the old one */
   if (candidate_name &&
-      strcmp (profile->priv->name, candidate_name) == 0)
+      strcmp (self->priv->name, candidate_name) == 0)
     return FALSE;
 
   if (candidate_name != NULL)
     {
-      g_free (profile->priv->name);
-      profile->priv->name = g_strdup (candidate_name);
+      g_free (self->priv->name);
+      self->priv->name = g_strdup (candidate_name);
       return TRUE;
     }
   /* otherwise just leave the old name */
@@ -505,18 +493,18 @@ set_name (GMAudioProfile *profile,
 }
 
 static gboolean
-set_description (GMAudioProfile *profile,
+set_description (GMAudioProfile *self,
                  const char *candidate_description)
 {
   /* don't update if it's the same as the old one */
   if (candidate_description &&
-      strcmp (profile->priv->description, candidate_description) == 0)
+      strcmp (self->priv->description, candidate_description) == 0)
     return FALSE;
 
   if (candidate_description != NULL)
     {
-      g_free (profile->priv->description);
-      profile->priv->description = g_strdup (candidate_description);
+      g_free (self->priv->description);
+      self->priv->description = g_strdup (candidate_description);
       return TRUE;
     }
   /* otherwise just leave the old description */
@@ -525,18 +513,18 @@ set_description (GMAudioProfile *profile,
 }
 
 static gboolean
-set_pipeline (GMAudioProfile *profile,
+set_pipeline (GMAudioProfile *self,
               const char *candidate_pipeline)
 {
   /* don't update if it's the same as the old one */
   if (candidate_pipeline &&
-      strcmp (profile->priv->pipeline, candidate_pipeline) == 0)
+      strcmp (self->priv->pipeline, candidate_pipeline) == 0)
     return FALSE;
 
   if (candidate_pipeline != NULL)
     {
-      g_free (profile->priv->pipeline);
-      profile->priv->pipeline = g_strdup (candidate_pipeline);
+      g_free (self->priv->pipeline);
+      self->priv->pipeline = g_strdup (candidate_pipeline);
       return TRUE;
     }
   /* otherwise just leave the old pipeline */
@@ -545,18 +533,18 @@ set_pipeline (GMAudioProfile *profile,
 }
 
 static gboolean
-set_extension (GMAudioProfile *profile,
+set_extension (GMAudioProfile *self,
                const char *candidate_extension)
 {
   /* don't update if it's the same as the old one */
   if (candidate_extension &&
-      strcmp (profile->priv->extension, candidate_extension) == 0)
+      strcmp (self->priv->extension, candidate_extension) == 0)
     return FALSE;
 
   if (candidate_extension != NULL)
     {
-      g_free (profile->priv->extension);
-      profile->priv->extension = g_strdup (candidate_extension);
+      g_free (self->priv->extension);
+      self->priv->extension = g_strdup (candidate_extension);
       return TRUE;
     }
   /* otherwise just leave the old extension */
@@ -582,14 +570,14 @@ profile_change_notify (GConfClient *client,
                        GConfEntry  *entry,
                        gpointer     user_data)
 {
-  GMAudioProfile *profile;
+  GMAudioProfile *self;
   const char *key;
   GConfValue *val;
   GMAudioSettingMask mask; /* to keep track of what has changed */
 
-  profile = GM_AUDIO_PROFILE (user_data);
-  GMP_DEBUG("profile_change_notify: start in profile with name %s\n",
-           profile->priv->name);
+  self = GM_AUDIO_PROFILE (user_data);
+  GST_DEBUG ("profile_change_notify: start in profile with name %s\n",
+           self->priv->name);
 
   val = gconf_entry_get_value (entry);
 
@@ -605,9 +593,9 @@ else if (strcmp (key, KName) == 0)                                      \
     if (val && val->type == GCONF_VALUE_STRING)                         \
       setting = gconf_value_get_string (val);                           \
                                                                         \
-    mask.FName = set_##FName (profile, setting);                        \
+    mask.FName = set_##FName (self, setting);                           \
                                                                         \
-    profile->priv->locked.FName = !gconf_entry_get_is_writable (entry);
+    self->priv->locked.FName = !gconf_entry_get_is_writable (entry);
 
 /* booleans are set directly on the profile priv variable */
 #define UPDATE_BOOLEAN(KName, FName, Preset)                            \
@@ -619,13 +607,13 @@ else if (strcmp (key, KName) == 0)                                      \
     if (val && val->type == GCONF_VALUE_BOOL)                           \
       setting = gconf_value_get_bool (val);                             \
                                                                         \
-    if (setting != profile->priv->FName)                                \
+    if (setting != self->priv->FName)                                   \
       {                                                                 \
         mask.FName = TRUE;                                              \
-        profile->priv->FName = setting;                                 \
+        self->priv->FName = setting;                                    \
       }                                                                 \
                                                                         \
-    profile->priv->locked.FName = !gconf_entry_get_is_writable (entry);
+    self->priv->locked.FName = !gconf_entry_get_is_writable (entry);
 
   if (0)
   {
@@ -641,10 +629,10 @@ else if (strcmp (key, KName) == 0)                                      \
 
   if (!(gm_audio_setting_mask_is_empty (&mask)))
   {
-    GMP_DEBUG("emit changed\n");
-    emit_changed (profile, &mask);
+    GST_DEBUG ("emit changed\n");
+    emit_changed (self, &mask);
   }
-  GMP_DEBUG("PROFILE_CHANGE_NOTIFY: changed stuff\n");
+  GST_DEBUG ("PROFILE_CHANGE_NOTIFY: changed stuff\n");
 }
 
 /* GConf notification callback for profile_list */
@@ -659,7 +647,7 @@ gm_audio_profile_list_notify (GConfClient *client,
   GSList *string_list;
   GSList *tmp;
 
-  GMP_DEBUG("profile_list changed\n");
+  GST_DEBUG ("profile_list changed\n");
   val = gconf_entry_get_value (entry);
 
   if (val == NULL ||
@@ -752,18 +740,18 @@ gm_audio_profile_initialize (GConfClient *conf)
 }
 
 static void
-emit_changed (GMAudioProfile           *profile,
+emit_changed (GMAudioProfile           *self,
               const GMAudioSettingMask *mask)
 {
-  profile->priv->in_notification_count += 1;
-  g_signal_emit (G_OBJECT (profile), signals[CHANGED], 0, mask);
-  profile->priv->in_notification_count -= 1;
+  self->priv->in_notification_count += 1;
+  g_signal_emit (G_OBJECT (self), signals[CHANGED], 0, mask);
+  self->priv->in_notification_count -= 1;
 }
 
 
 /* update the given GMAudioProfile from GConf */
 static void
-gm_audio_profile_update (GMAudioProfile *profile)
+gm_audio_profile_update (GMAudioProfile *self)
 {
   GMAudioSettingMask locked;
   GMAudioSettingMask mask;
@@ -771,34 +759,34 @@ gm_audio_profile_update (GMAudioProfile *profile)
   memset (&mask, '\0', sizeof (mask));
   memset (&locked, '\0', sizeof (locked));
 
-#define UPDATE_BOOLEAN(KName, FName) \
-{ \
-  char *key = gconf_concat_dir_and_key (profile->priv->profile_dir, KName); \
-  gboolean val = gconf_client_get_bool (profile->priv->conf, key, NULL);    \
-                                                                            \
-  if (val != profile->priv->FName) \
-  { \
-    mask.FName = TRUE; \
-    profile->priv->FName = val; \
-  } \
-                                                                              \
-  locked.FName = \
-    !gconf_client_key_is_writable (profile->priv->conf, key, NULL); \
-                                                                              \
-  g_free (key); \
+#define UPDATE_BOOLEAN(KName, FName)                                    \
+{                                                                       \
+  char *key = gconf_concat_dir_and_key (self->priv->profile_dir, KName); \
+  gboolean val = gconf_client_get_bool (self->priv->conf, key, NULL);   \
+                                                                        \
+  if (val != self->priv->FName)                                         \
+  {                                                                     \
+    mask.FName = TRUE;                                                  \
+    self->priv->FName = val;                                            \
+  }                                                                     \
+                                                                        \
+  locked.FName =                                                        \
+    !gconf_client_key_is_writable (self->priv->conf, key, NULL);        \
+                                                                        \
+  g_free (key);                                                         \
 }
-#define UPDATE_STRING(KName, FName) \
-{ \
-  char *key = gconf_concat_dir_and_key (profile->priv->profile_dir, KName); \
-  char *val = gconf_client_get_string (profile->priv->conf, key, NULL); \
-                                                                               \
-  mask.FName = set_##FName (profile, val); \
-                                                                               \
-  locked.FName = \
-    !gconf_client_key_is_writable (profile->priv->conf, key, NULL); \
-                                                                               \
-  g_free (val); \
-  g_free (key); \
+#define UPDATE_STRING(KName, FName)                                     \
+{                                                                       \
+  char *key = gconf_concat_dir_and_key (self->priv->profile_dir, KName); \
+  char *val = gconf_client_get_string (self->priv->conf, key, NULL);    \
+                                                                        \
+  mask.FName = set_##FName (self, val);                                 \
+                                                                        \
+  locked.FName =                                                        \
+    !gconf_client_key_is_writable (self->priv->conf, key, NULL);        \
+                                                                        \
+  g_free (val);                                                         \
+  g_free (key);                                                         \
 }
   UPDATE_STRING  (KEY_NAME,        name);
   UPDATE_STRING  (KEY_DESCRIPTION, description);
@@ -808,7 +796,7 @@ gm_audio_profile_update (GMAudioProfile *profile)
 
 #undef UPDATE_BOOLEAN
 #undef UPDATE_STRING
-  profile->priv->locked = locked;
+  self->priv->locked = locked;
   //FIXME: we don't use mask ?
 }
 
@@ -896,7 +884,7 @@ gm_audio_profile_lookup (const char *id)
 
   if (profiles)
   {
-    GMP_DEBUG("a_p_l: profiles exists, returning hash table lookup of %s\n", id);
+    GST_DEBUG ("a_p_l: profiles exists, returning hash table lookup of %s\n", id);
     return g_hash_table_lookup (profiles, id);
   }
   else
@@ -904,35 +892,35 @@ gm_audio_profile_lookup (const char *id)
 }
 
 void
-gm_audio_profile_forget (GMAudioProfile *profile)
+gm_audio_profile_forget (GMAudioProfile *self)
 {
-  GMP_DEBUG("audio_profile_forget: forgetting name %s\n",
-           gm_audio_profile_get_name (profile));
-  if (!profile->priv->forgotten)
+  GST_DEBUG ("audio_profile_forget: forgetting name %s\n",
+           gm_audio_profile_get_name (self));
+  if (!self->priv->forgotten)
   {
     GError *err;
 
     err = NULL;
-    GMP_DEBUG("audio_profile_forget: removing from gconf\n");
+    GST_DEBUG ("audio_profile_forget: removing from gconf\n");
     /* FIXME: remove_dir doesn't actually work.  Either unset all keys
      * manually or use recursive_unset on HEAD */
-    gconf_client_remove_dir (profile->priv->conf,
-                             profile->priv->profile_dir,
+    gconf_client_remove_dir (self->priv->conf,
+                             self->priv->profile_dir,
                              &err);
     if (err)
     {
       g_printerr (_("There was an error forgetting profile path %s. (%s)\n"),
-                  profile->priv->profile_dir, err->message);
+                  self->priv->profile_dir, err->message);
                   g_error_free (err);
     }
 
-    g_hash_table_remove (profiles, profile->priv->name);
-    profile->priv->forgotten = TRUE;
+    g_hash_table_remove (profiles, self->priv->id);
+    self->priv->forgotten = TRUE;
 
-    g_signal_emit (G_OBJECT (profile), signals[FORGOTTEN], 0);
+    g_signal_emit (G_OBJECT (self), signals[FORGOTTEN], 0);
   }
   else
-    GMP_DEBUG("audio_profile_forget: profile->priv->forgotten\n");
+    GST_DEBUG ("audio_profile_forget: profile->priv->forgotten\n");
 }
 
 gboolean
@@ -970,9 +958,8 @@ gm_audio_profile_create (const char  *name,
   GSList *id_list = NULL;
   GList *tmp;
 
-  GMP_DEBUG("a_p_c: Creating profile for %s\n", name);
-  /* This is for extra bonus paranoia against CORBA reentrancy */
-  //g_object_ref (G_OBJECT (transient_parent));
+  GST_DEBUG ("a_p_c: Creating profile for %s\n", name);
+
 #define BAIL_OUT_CHECK() do {                           \
       if (err != NULL)					\
        goto cleanup;                                    \
@@ -981,7 +968,7 @@ gm_audio_profile_create (const char  *name,
   /* Pick a unique name for storing in gconf (based on visible name) */
   profile_id = gconf_escape_key (name, -1);
   s = g_strdup (profile_id);
-  GMP_DEBUG("profile_id: %s\n", s);
+  GST_DEBUG ("profile_id: %s\n", s);
   i = 0;
   while (gm_audio_profile_lookup (s))
   {
@@ -1054,7 +1041,7 @@ gm_audio_profile_create (const char  *name,
 
   id_list = g_slist_prepend (id_list, g_strdup (profile_id));
 
-  GMP_DEBUG("setting gconf list\n");
+  GST_DEBUG ("setting gconf list\n");
   err = NULL;
   gconf_client_set_list (conf,
                          CONF_GLOBAL_PREFIX"/profile_list",
@@ -1083,42 +1070,14 @@ gm_audio_profile_create (const char  *name,
     g_slist_free (id_list);
   }
 
-  /* FIXME
-  if (err)
-    {
-      if (GTK_WIDGET_VISIBLE (transient_parent))
-        {
-          GtkWidget *dialog;
-
-          dialog = gtk_message_dialog_new (GTK_WINDOW (transient_parent),
-                                           GTK_DIALOG_DESTROY_WITH_PARENT,
-                                           GTK_MESSAGE_ERROR,
-                                           GTK_BUTTONS_CLOSE,
-                                           _("There was an error creating the profile \"%s\""),
-                                           visible_id);
-          g_signal_connect (G_OBJECT (dialog), "response",
-                            G_CALLBACK (gtk_widget_destroy),
-                            NULL);
-
-          dialog_add_details (GTK_DIALOG (dialog),
-                              err->message);
-
-          gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-
-          gtk_widget_show (dialog);
-        }
-
-      g_error_free (err);
-    }
-  */
   if (err)
   {
-    GMP_DEBUG("WARNING: error: %s !\n", err->message);
+    GST_DEBUG ("WARNING: error: %s !\n", err->message);
     *error = err;
   }
 
-  //g_object_unref (G_OBJECT (transient_parent));
-  GMP_DEBUG("a_p_c: done\n");
+  GST_DEBUG ("a_p_c: done\n");
+
   return profile_id;
 }
 
@@ -1159,7 +1118,7 @@ gm_audio_profile_delete_list (GConfClient *conf,
 
   g_list_free (current_profiles);
   err = NULL;
-  GMP_DEBUG("setting profile_list in GConf\n");
+  GST_DEBUG ("setting profile_list in GConf\n");
   gconf_client_set_list (conf,
                          CONF_GLOBAL_PREFIX"/profile_list",
                          GCONF_VALUE_STRING,
